"""Top-level package for Tank Forecaster."""

__author__ = """Jim Vogel"""
__email__ = "james.vogel@capspire.com"
__version__ = "0.3.56"

# from tank_forecaster.tank_forecaster import decomp, events, forecaster, validation



import numpy as np
import pandas as pd

from tank_forecaster import forecaster
from tank_forecaster.decomp import generic_hh_seasonality


def is_a_valid_forecast_dataframe(df):
    return (
        type(df) is pd.core.frame.DataFrame
        and len(df) == 144
        and "ds" in df
        and "yhat" in df
        and type(df.ds.iloc[-1]) is pd._libs.tslibs.timestamps.Timestamp
        and type(df.yhat.iloc[-1]) is np.float64
    )


def test_near_approx_returns_a_valid_dataframe():
    x = forecaster.forecast_near_approx(
        daily_lift_est=0, hh_seasonality=generic_hh_seasonality
    )
    assert is_a_valid_forecast_dataframe(x)


def test_near_approx_returns_none():
    assert (
        forecaster.forecast_near_approx(daily_lift_est=None, hh_seasonality=None)
        is None
    )


def test_near_returns_none():
    assert forecaster.forecast_near(None) is None


def test_near_full_data_returns_a_valid_dataframe(tank_full_data):
    x = forecaster.forecast_near(tank_history=tank_full_data)
    assert is_a_valid_forecast_dataframe(x)


def test_near_approx_start_date():
    x = forecaster.forecast_near_approx(
        daily_lift_est=0, hh_seasonality=generic_hh_seasonality, start_time="2020-01-01"
    )
    assert is_a_valid_forecast_dataframe(x)


def test_near_start_date(tank_full_data):
    x = forecaster.forecast_near(tank_history=tank_full_data, start_time="2020-01-01")
    assert is_a_valid_forecast_dataframe(x)
    assert str(x.ds.iloc[0]) == "2020-01-01 00:00:00"



from tank_forecaster import decomp


def test_decomp_tank_none_returns_correct_len(tank_full_data):
    x = decomp.decompose_tank(None)
    assert len(x) == 48


def test_decomp_tank_little_returns_correct_len(tank_little_data):
    x = decomp.decompose_tank(tank_little_data)
    assert len(x) == 48


def test_decomp_tank_full_data_returns_correct_len(tank_full_data):
    x = decomp.decompose_tank(tank_full_data)
    assert len(x) == 48



import numpy as np
import pandas as pd

from tank_forecaster import forecaster
from tank_forecaster.decomp import (generic_weekly_seasonality,
                                    generic_yearly_seasonality)


def is_a_valid_forecast_dataframe(df):
    return (
        type(df) is pd.core.frame.DataFrame
        and len(df) == 90
        and "ds" in df
        and "yhat" in df
        and type(df.ds.iloc[-1]) is pd._libs.tslibs.timestamps.Timestamp
        and type(df.yhat.iloc[-1]) is np.float64
    )


def test_far_returns_a_valid_dataframe():
    x = forecaster.forecast_far(
        daily_lift_est=5000,
        yearly_seasonality=generic_yearly_seasonality,
        weekly_seasonality=generic_weekly_seasonality,
    )
    assert is_a_valid_forecast_dataframe(x)


def test_far_start_date_works():
    x = forecaster.forecast_far(
        daily_lift_est=5000,
        yearly_seasonality=generic_yearly_seasonality,
        weekly_seasonality=generic_weekly_seasonality,
        start_date="2020-01-01",
    )
    assert is_a_valid_forecast_dataframe(x)
    assert str(x.ds.iloc[0]) == "2020-01-01 00:00:00"
    assert str(x.ds.iloc[-1]) == "2020-03-30 00:00:00"


if __name__ == "__main__":
    pass



import numpy as np
import pandas as pd

from tank_forecaster import validation


def is_validated_data(x):
    return (
        type(x) is pd.core.frame.DataFrame
        and len(x["ds"]) != 0
        and len(x["y"]) != 0
        and type(x.ds.iloc[-1]) is pd._libs.tslibs.timestamps.Timestamp
        and type(x.y.iloc[-1]) is np.float64
    )


def test_format_tank_none_returns_none():
    x = validation.format_tank(None)
    assert x is None


def test_format_tank_empty_returns_none():
    x = validation.format_tank([])
    assert x is None


def test_format_tank_deletes_first_and_list(tank_two_input):
    x = validation.format_tank(tank_two_input)
    assert len(x) == 0


def test_format_tank_returns_validated_data(tank_little_input):
    x = validation.format_tank(tank_little_input)
    assert is_validated_data(x)


def test_format_sales_no_data_returns_none():
    x = validation.format_sales(None)
    assert x is None


def test_format_sales_empty_list_returns_none():
    x = validation.format_sales([])
    assert x is None


def test_format_sales_proper(sales_little_input):
    x = validation.format_sales(sales_little_input)
    assert is_validated_data(x)
